/*!40101 SET NAMES utf8mb4 */;

/*!40101 SET SQL_MODE=''*/;

/*!40014 SET @OLD_UNIQUE_CHECKS=@@UNIQUE_CHECKS, UNIQUE_CHECKS=0 */;
/*!40101 SET @OLD_SQL_MODE=@@SQL_MODE, SQL_MODE='NO_AUTO_VALUE_ON_ZERO' */;
/*!40111 SET @OLD_SQL_NOTES=@@SQL_NOTES, SQL_NOTES=0 */;
CREATE DATABASE /*!32312 IF NOT EXISTS*/`tmerclub_seckill` /*!40100 DEFAULT CHARACTER SET utf8mb4 COLLATE utf8mb4_general_ci */ /*!80016 DEFAULT ENCRYPTION='N' */;

USE `tmerclub_seckill`;

/*Table structure for table `seckill` */

DROP TABLE IF EXISTS `seckill`;

CREATE TABLE `seckill` (
  `seckill_id` bigint NOT NULL AUTO_INCREMENT COMMENT '秒杀活动id',
  `create_time` datetime NOT NULL DEFAULT CURRENT_TIMESTAMP COMMENT '创建时间',
  `update_time` datetime NOT NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP COMMENT '更新时间',
  `seckill_name` varchar(36) DEFAULT NULL COMMENT '活动名称',
  `start_time` datetime DEFAULT NULL COMMENT '开始日期',
  `end_time` datetime DEFAULT NULL COMMENT '结束日期',
  `selected_lot` int DEFAULT NULL COMMENT '所选批次',
  `category_id` bigint DEFAULT NULL COMMENT '所选分类',
  `seckill_tag` varchar(36) DEFAULT NULL COMMENT '活动标签',
  `max_num` int DEFAULT NULL COMMENT '限购数量',
  `max_cancel_time` int DEFAULT NULL COMMENT '取消订单时间',
  `shop_id` bigint DEFAULT NULL COMMENT '店铺id',
  `is_delete` tinyint DEFAULT NULL COMMENT '0 未删除 1已删除',
  `status` tinyint DEFAULT NULL COMMENT '状态(0:失效、1:正常、2:违规下架、3:等待审核)',
  `spu_id` bigint DEFAULT NULL COMMENT '商品id',
  `seckill_total_stocks` int DEFAULT NULL COMMENT '秒杀活动剩余总库存',
  `seckill_origin_stocks` int DEFAULT NULL COMMENT '秒杀活动原始库存',
  `seckill_price` bigint DEFAULT NULL COMMENT '秒杀活动最低价',
  `replenish` int DEFAULT NULL COMMENT '补充库存 0不补充 1补充',
  PRIMARY KEY (`seckill_id`),
  KEY `key_spu_id` (`spu_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='秒杀信息';

/*Data for the table `seckill` */

/*Table structure for table `seckill_category` */

DROP TABLE IF EXISTS `seckill_category`;

CREATE TABLE `seckill_category` (
  `category_id` bigint unsigned NOT NULL AUTO_INCREMENT COMMENT '秒杀分类id',
  `create_time` datetime NOT NULL DEFAULT CURRENT_TIMESTAMP COMMENT '创建时间',
  `update_time` datetime NOT NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP COMMENT '更新时间',
  `name` varchar(255) NOT NULL DEFAULT '' COMMENT '分类名称',
  `seq` int DEFAULT '0' COMMENT '排序',
  PRIMARY KEY (`category_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='秒杀分类信息';

/*Data for the table `seckill_category` */

/*Table structure for table `seckill_order` */

DROP TABLE IF EXISTS `seckill_order`;

CREATE TABLE `seckill_order` (
  `seckill_order_id` bigint NOT NULL AUTO_INCREMENT COMMENT '秒杀订单id',
  `create_time` datetime NOT NULL DEFAULT CURRENT_TIMESTAMP COMMENT '创建时间',
  `update_time` datetime NOT NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP COMMENT '更新时间',
  `seckill_id` bigint DEFAULT NULL COMMENT '秒杀订单id',
  `user_id` bigint DEFAULT NULL COMMENT '用户id',
  `order_id` bigint DEFAULT NULL COMMENT '订单id',
  `prod_count` int DEFAULT NULL COMMENT '秒杀到的商品数量',
  `spu_id` bigint DEFAULT NULL COMMENT '商品id',
  `state` tinyint DEFAULT NULL COMMENT '-1指无效，0指待付款，1指已付款',
  `seckill_sku_id` bigint DEFAULT NULL COMMENT '秒杀到的秒杀商品sku',
  PRIMARY KEY (`seckill_order_id`),
  KEY `key_seckill_id` (`seckill_id`),
  KEY `key_user_id` (`user_id`),
  KEY `key_order_id` (`order_id`),
  KEY `key_spu_id` (`spu_id`),
  KEY `key_seckill_sku_id` (`seckill_sku_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='秒杀订单';

/*Data for the table `seckill_order` */

/*Table structure for table `seckill_sku` */

DROP TABLE IF EXISTS `seckill_sku`;

CREATE TABLE `seckill_sku` (
  `seckill_sku_id` bigint NOT NULL AUTO_INCREMENT COMMENT '秒杀活动单个skuid',
  `create_time` datetime NOT NULL DEFAULT CURRENT_TIMESTAMP COMMENT '创建时间',
  `update_time` datetime NOT NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP COMMENT '更新时间',
  `sku_id` bigint DEFAULT NULL COMMENT 'skuId',
  `seckill_id` bigint DEFAULT NULL COMMENT '秒杀活动id',
  `seckill_stocks` int DEFAULT NULL COMMENT '用于秒杀的库存',
  `seckill_price` bigint DEFAULT NULL COMMENT '秒杀价格',
  `seckill_origin_stocks` INT NULL COMMENT '秒杀活动原始库存',
  PRIMARY KEY (`seckill_sku_id`),
  KEY `key_sku_id` (`sku_id`),
  KEY `key_seckill_id` (`seckill_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='秒杀活动sku';

/*Data for the table `seckill_sku` */

DROP TABLE IF EXISTS `seckill_stock_point_sku`;
CREATE TABLE `seckill_stock_point_sku` (
        `seckill_stock_point_sku_id` bigint unsigned NOT NULL AUTO_INCREMENT COMMENT '库存商品关联skuid',
        `stock_point_id` bigint NOT NULL COMMENT '库存点id',
        `stock_point_type` tinyint NOT NULL COMMENT '库存点类型 1仓库 2门店',
        `sku_id` bigint DEFAULT NULL COMMENT 'sku_id',
        `seckill_sku_id` bigint DEFAULT NULL COMMENT '秒杀活动skuid',
        `status` tinyint DEFAULT '0' COMMENT '状态 1:enable, 0:disable, -1:deleted',
        `create_time` datetime NOT NULL DEFAULT CURRENT_TIMESTAMP COMMENT '创建时间',
        `update_time` datetime NOT NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP COMMENT '更新时间',
        `type` tinyint DEFAULT NULL COMMENT '仓库类型（0默认仓库，1区域仓库）',
        `seckill_origin_stocks` int DEFAULT NULL COMMENT '秒杀库存点原始库存',
        PRIMARY KEY (`seckill_stock_point_sku_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci;

/*Table structure for table `leaf_alloc` */

CREATE TABLE IF NOT EXISTS `leaf_alloc` (
  `biz_tag` varchar(128) CHARACTER SET utf8mb4 COLLATE utf8mb4_general_ci NOT NULL DEFAULT '' COMMENT '区分业务',
  `max_id` bigint unsigned NOT NULL DEFAULT '1' COMMENT '该biz_tag目前所被分配的ID号段的最大值',
  `step` int NOT NULL COMMENT '每次分配的号段长度',
  `update_time` timestamp NOT NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP COMMENT '更新时间',
  `description` varchar(256) CHARACTER SET utf8mb4 COLLATE utf8mb4_general_ci DEFAULT NULL COMMENT '描述',
  PRIMARY KEY (`biz_tag`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci;

/*Data for the table `leaf_alloc` */

insert into `leaf_alloc` (`biz_tag`, `max_id`, `step`, `description`) values
('tmerclub-order-000','1','1000','订单id'),
('tmerclub-order-001','1','1000','订单id'),
('tmerclub-order-002','1','1000','订单id'),
('tmerclub-order-003','1','1000','订单id'),
('tmerclub-order-004','1','1000','订单id'),
('tmerclub-order-005','1','1000','订单id'),
('tmerclub-order-006','1','1000','订单id'),
('tmerclub-order-007','1','1000','订单id'),
('tmerclub-order-008','1','1000','订单id'),
('tmerclub-order-009','1','1000','订单id'),
('tmerclub-order-010','1','1000','订单id'),
('tmerclub-order-011','1','1000','订单id'),
('tmerclub-order-012','1','1000','订单id'),
('tmerclub-order-013','1','1000','订单id'),
('tmerclub-order-014','1','1000','订单id'),
('tmerclub-order-015','1','1000','订单id'),
('tmerclub-order-016','1','1000','订单id'),
('tmerclub-order-017','1','1000','订单id'),
('tmerclub-order-018','1','1000','订单id'),
('tmerclub-order-019','1','1000','订单id'),
('tmerclub-order-020','1','1000','订单id'),
('tmerclub-order-021','1','1000','订单id'),
('tmerclub-order-022','1','1000','订单id'),
('tmerclub-order-023','1','1000','订单id'),
('tmerclub-order-024','1','1000','订单id'),
('tmerclub-order-025','1','1000','订单id'),
('tmerclub-order-026','1','1000','订单id'),
('tmerclub-order-027','1','1000','订单id'),
('tmerclub-order-028','1','1000','订单id'),
('tmerclub-order-029','1','1000','订单id'),
('tmerclub-order-030','1','1000','订单id'),
('tmerclub-order-031','1','1000','订单id'),
('tmerclub-order-032','1','1000','订单id'),
('tmerclub-order-033','1','1000','订单id'),
('tmerclub-order-034','1','1000','订单id'),
('tmerclub-order-035','1','1000','订单id'),
('tmerclub-order-036','1','1000','订单id'),
('tmerclub-order-037','1','1000','订单id'),
('tmerclub-order-038','1','1000','订单id'),
('tmerclub-order-039','1','1000','订单id'),
('tmerclub-order-040','1','1000','订单id'),
('tmerclub-order-041','1','1000','订单id'),
('tmerclub-order-042','1','1000','订单id'),
('tmerclub-order-043','1','1000','订单id'),
('tmerclub-order-044','1','1000','订单id'),
('tmerclub-order-045','1','1000','订单id'),
('tmerclub-order-046','1','1000','订单id'),
('tmerclub-order-047','1','1000','订单id'),
('tmerclub-order-048','1','1000','订单id'),
('tmerclub-order-049','1','1000','订单id'),
('tmerclub-order-050','1','1000','订单id'),
('tmerclub-order-051','1','1000','订单id'),
('tmerclub-order-052','1','1000','订单id'),
('tmerclub-order-053','1','1000','订单id'),
('tmerclub-order-054','1','1000','订单id'),
('tmerclub-order-055','1','1000','订单id'),
('tmerclub-order-056','1','1000','订单id'),
('tmerclub-order-057','1','1000','订单id'),
('tmerclub-order-058','1','1000','订单id'),
('tmerclub-order-059','1','1000','订单id'),
('tmerclub-order-060','1','1000','订单id'),
('tmerclub-order-061','1','1000','订单id'),
('tmerclub-order-062','1','1000','订单id'),
('tmerclub-order-063','1','1000','订单id'),
('tmerclub-order-064','1','1000','订单id'),
('tmerclub-order-065','1','1000','订单id'),
('tmerclub-order-066','1','1000','订单id'),
('tmerclub-order-067','1','1000','订单id'),
('tmerclub-order-068','1','1000','订单id'),
('tmerclub-order-069','1','1000','订单id'),
('tmerclub-order-070','1','1000','订单id'),
('tmerclub-order-071','1','1000','订单id'),
('tmerclub-order-072','1','1000','订单id'),
('tmerclub-order-073','1','1000','订单id'),
('tmerclub-order-074','1','1000','订单id'),
('tmerclub-order-075','1','1000','订单id'),
('tmerclub-order-076','1','1000','订单id'),
('tmerclub-order-077','1','1000','订单id'),
('tmerclub-order-078','1','1000','订单id'),
('tmerclub-order-079','1','1000','订单id'),
('tmerclub-order-080','1','1000','订单id'),
('tmerclub-order-081','1','1000','订单id'),
('tmerclub-order-082','1','1000','订单id'),
('tmerclub-order-083','1','1000','订单id'),
('tmerclub-order-084','1','1000','订单id'),
('tmerclub-order-085','1','1000','订单id'),
('tmerclub-order-086','1','1000','订单id'),
('tmerclub-order-087','1','1000','订单id'),
('tmerclub-order-088','1','1000','订单id'),
('tmerclub-order-089','1','1000','订单id'),
('tmerclub-order-090','1','1000','订单id'),
('tmerclub-order-091','1','1000','订单id'),
('tmerclub-order-092','1','1000','订单id'),
('tmerclub-order-093','1','1000','订单id'),
('tmerclub-order-094','1','1000','订单id'),
('tmerclub-order-095','1','1000','订单id'),
('tmerclub-order-096','1','1000','订单id'),
('tmerclub-order-097','1','1000','订单id'),
('tmerclub-order-098','1','1000','订单id'),
('tmerclub-order-099','1','1000','订单id'),
('tmerclub-order-100','1','1000','订单id'),
('tmerclub-order-101','1','1000','订单id'),
('tmerclub-order-102','1','1000','订单id'),
('tmerclub-order-103','1','1000','订单id'),
('tmerclub-order-104','1','1000','订单id'),
('tmerclub-order-105','1','1000','订单id'),
('tmerclub-order-106','1','1000','订单id'),
('tmerclub-order-107','1','1000','订单id'),
('tmerclub-order-108','1','1000','订单id'),
('tmerclub-order-109','1','1000','订单id'),
('tmerclub-order-110','1','1000','订单id'),
('tmerclub-order-111','1','1000','订单id'),
('tmerclub-order-112','1','1000','订单id'),
('tmerclub-order-113','1','1000','订单id'),
('tmerclub-order-114','1','1000','订单id'),
('tmerclub-order-115','1','1000','订单id'),
('tmerclub-order-116','1','1000','订单id'),
('tmerclub-order-117','1','1000','订单id'),
('tmerclub-order-118','1','1000','订单id'),
('tmerclub-order-119','1','1000','订单id'),
('tmerclub-order-120','1','1000','订单id'),
('tmerclub-order-121','1','1000','订单id'),
('tmerclub-order-122','1','1000','订单id'),
('tmerclub-order-123','1','1000','订单id'),
('tmerclub-order-124','1','1000','订单id'),
('tmerclub-order-125','1','1000','订单id'),
('tmerclub-order-126','1','1000','订单id'),
('tmerclub-order-127','1','1000','订单id'),
('tmerclub-order-128','1','1000','订单id'),
('tmerclub-order-129','1','1000','订单id'),
('tmerclub-order-130','1','1000','订单id'),
('tmerclub-order-131','1','1000','订单id'),
('tmerclub-order-132','1','1000','订单id'),
('tmerclub-order-133','1','1000','订单id'),
('tmerclub-order-134','1','1000','订单id'),
('tmerclub-order-135','1','1000','订单id'),
('tmerclub-order-136','1','1000','订单id'),
('tmerclub-order-137','1','1000','订单id'),
('tmerclub-order-138','1','1000','订单id'),
('tmerclub-order-139','1','1000','订单id'),
('tmerclub-order-140','1','1000','订单id'),
('tmerclub-order-141','1','1000','订单id'),
('tmerclub-order-142','1','1000','订单id'),
('tmerclub-order-143','1','1000','订单id'),
('tmerclub-order-144','1','1000','订单id'),
('tmerclub-order-145','1','1000','订单id'),
('tmerclub-order-146','1','1000','订单id'),
('tmerclub-order-147','1','1000','订单id'),
('tmerclub-order-148','1','1000','订单id'),
('tmerclub-order-149','1','1000','订单id'),
('tmerclub-order-150','1','1000','订单id'),
('tmerclub-order-151','1','1000','订单id'),
('tmerclub-order-152','1','1000','订单id'),
('tmerclub-order-153','1','1000','订单id'),
('tmerclub-order-154','1','1000','订单id'),
('tmerclub-order-155','1','1000','订单id'),
('tmerclub-order-156','1','1000','订单id'),
('tmerclub-order-157','1','1000','订单id'),
('tmerclub-order-158','1','1000','订单id'),
('tmerclub-order-159','1','1000','订单id'),
('tmerclub-order-160','1','1000','订单id'),
('tmerclub-order-161','1','1000','订单id'),
('tmerclub-order-162','1','1000','订单id'),
('tmerclub-order-163','1','1000','订单id'),
('tmerclub-order-164','1','1000','订单id'),
('tmerclub-order-165','1','1000','订单id'),
('tmerclub-order-166','1','1000','订单id'),
('tmerclub-order-167','1','1000','订单id'),
('tmerclub-order-168','1','1000','订单id'),
('tmerclub-order-169','1','1000','订单id'),
('tmerclub-order-170','1','1000','订单id'),
('tmerclub-order-171','1','1000','订单id'),
('tmerclub-order-172','1','1000','订单id'),
('tmerclub-order-173','1','1000','订单id'),
('tmerclub-order-174','1','1000','订单id'),
('tmerclub-order-175','1','1000','订单id'),
('tmerclub-order-176','1','1000','订单id'),
('tmerclub-order-177','1','1000','订单id'),
('tmerclub-order-178','1','1000','订单id'),
('tmerclub-order-179','1','1000','订单id'),
('tmerclub-order-180','1','1000','订单id'),
('tmerclub-order-181','1','1000','订单id'),
('tmerclub-order-182','1','1000','订单id'),
('tmerclub-order-183','1','1000','订单id'),
('tmerclub-order-184','1','1000','订单id'),
('tmerclub-order-185','1','1000','订单id'),
('tmerclub-order-186','1','1000','订单id'),
('tmerclub-order-187','1','1000','订单id'),
('tmerclub-order-188','1','1000','订单id'),
('tmerclub-order-189','1','1000','订单id'),
('tmerclub-order-190','1','1000','订单id'),
('tmerclub-order-191','1','1000','订单id'),
('tmerclub-order-192','1','1000','订单id'),
('tmerclub-order-193','1','1000','订单id'),
('tmerclub-order-194','1','1000','订单id'),
('tmerclub-order-195','1','1000','订单id'),
('tmerclub-order-196','1','1000','订单id'),
('tmerclub-order-197','1','1000','订单id'),
('tmerclub-order-198','1','1000','订单id'),
('tmerclub-order-199','1','1000','订单id'),
('tmerclub-order-200','1','1000','订单id'),
('tmerclub-order-201','1','1000','订单id'),
('tmerclub-order-202','1','1000','订单id'),
('tmerclub-order-203','1','1000','订单id'),
('tmerclub-order-204','1','1000','订单id'),
('tmerclub-order-205','1','1000','订单id'),
('tmerclub-order-206','1','1000','订单id'),
('tmerclub-order-207','1','1000','订单id'),
('tmerclub-order-208','1','1000','订单id'),
('tmerclub-order-209','1','1000','订单id'),
('tmerclub-order-210','1','1000','订单id'),
('tmerclub-order-211','1','1000','订单id'),
('tmerclub-order-212','1','1000','订单id'),
('tmerclub-order-213','1','1000','订单id'),
('tmerclub-order-214','1','1000','订单id'),
('tmerclub-order-215','1','1000','订单id'),
('tmerclub-order-216','1','1000','订单id'),
('tmerclub-order-217','1','1000','订单id'),
('tmerclub-order-218','1','1000','订单id'),
('tmerclub-order-219','1','1000','订单id'),
('tmerclub-order-220','1','1000','订单id'),
('tmerclub-order-221','1','1000','订单id'),
('tmerclub-order-222','1','1000','订单id'),
('tmerclub-order-223','1','1000','订单id'),
('tmerclub-order-224','1','1000','订单id'),
('tmerclub-order-225','1','1000','订单id'),
('tmerclub-order-226','1','1000','订单id'),
('tmerclub-order-227','1','1000','订单id'),
('tmerclub-order-228','1','1000','订单id'),
('tmerclub-order-229','1','1000','订单id'),
('tmerclub-order-230','1','1000','订单id'),
('tmerclub-order-231','1','1000','订单id'),
('tmerclub-order-232','1','1000','订单id'),
('tmerclub-order-233','1','1000','订单id'),
('tmerclub-order-234','1','1000','订单id'),
('tmerclub-order-235','1','1000','订单id'),
('tmerclub-order-236','1','1000','订单id'),
('tmerclub-order-237','1','1000','订单id'),
('tmerclub-order-238','1','1000','订单id'),
('tmerclub-order-239','1','1000','订单id'),
('tmerclub-order-240','1','1000','订单id'),
('tmerclub-order-241','1','1000','订单id'),
('tmerclub-order-242','1','1000','订单id'),
('tmerclub-order-243','1','1000','订单id'),
('tmerclub-order-244','1','1000','订单id'),
('tmerclub-order-245','1','1000','订单id'),
('tmerclub-order-246','1','1000','订单id'),
('tmerclub-order-247','1','1000','订单id'),
('tmerclub-order-248','1','1000','订单id'),
('tmerclub-order-249','1','1000','订单id'),
('tmerclub-order-250','1','1000','订单id'),
('tmerclub-order-251','1','1000','订单id'),
('tmerclub-order-252','1','1000','订单id'),
('tmerclub-order-253','1','1000','订单id'),
('tmerclub-order-254','1','1000','订单id'),
('tmerclub-order-255','1','1000','订单id'),
('tmerclub-order-256','1','1000','订单id'),
('tmerclub-order-257','1','1000','订单id'),
('tmerclub-order-258','1','1000','订单id'),
('tmerclub-order-259','1','1000','订单id'),
('tmerclub-order-260','1','1000','订单id'),
('tmerclub-order-261','1','1000','订单id'),
('tmerclub-order-262','1','1000','订单id'),
('tmerclub-order-263','1','1000','订单id'),
('tmerclub-order-264','1','1000','订单id'),
('tmerclub-order-265','1','1000','订单id'),
('tmerclub-order-266','1','1000','订单id'),
('tmerclub-order-267','1','1000','订单id'),
('tmerclub-order-268','1','1000','订单id'),
('tmerclub-order-269','1','1000','订单id'),
('tmerclub-order-270','1','1000','订单id'),
('tmerclub-order-271','1','1000','订单id'),
('tmerclub-order-272','1','1000','订单id'),
('tmerclub-order-273','1','1000','订单id'),
('tmerclub-order-274','1','1000','订单id'),
('tmerclub-order-275','1','1000','订单id'),
('tmerclub-order-276','1','1000','订单id'),
('tmerclub-order-277','1','1000','订单id'),
('tmerclub-order-278','1','1000','订单id'),
('tmerclub-order-279','1','1000','订单id'),
('tmerclub-order-280','1','1000','订单id'),
('tmerclub-order-281','1','1000','订单id'),
('tmerclub-order-282','1','1000','订单id'),
('tmerclub-order-283','1','1000','订单id'),
('tmerclub-order-284','1','1000','订单id'),
('tmerclub-order-285','1','1000','订单id'),
('tmerclub-order-286','1','1000','订单id'),
('tmerclub-order-287','1','1000','订单id'),
('tmerclub-order-288','1','1000','订单id'),
('tmerclub-order-289','1','1000','订单id'),
('tmerclub-order-290','1','1000','订单id'),
('tmerclub-order-291','1','1000','订单id'),
('tmerclub-order-292','1','1000','订单id'),
('tmerclub-order-293','1','1000','订单id'),
('tmerclub-order-294','1','1000','订单id'),
('tmerclub-order-295','1','1000','订单id'),
('tmerclub-order-296','1','1000','订单id'),
('tmerclub-order-297','1','1000','订单id'),
('tmerclub-order-298','1','1000','订单id'),
('tmerclub-order-299','1','1000','订单id'),
('tmerclub-order-300','1','1000','订单id'),
('tmerclub-order-301','1','1000','订单id'),
('tmerclub-order-302','1','1000','订单id'),
('tmerclub-order-303','1','1000','订单id'),
('tmerclub-order-304','1','1000','订单id'),
('tmerclub-order-305','1','1000','订单id'),
('tmerclub-order-306','1','1000','订单id'),
('tmerclub-order-307','1','1000','订单id'),
('tmerclub-order-308','1','1000','订单id'),
('tmerclub-order-309','1','1000','订单id'),
('tmerclub-order-310','1','1000','订单id'),
('tmerclub-order-311','1','1000','订单id'),
('tmerclub-order-312','1','1000','订单id'),
('tmerclub-order-313','1','1000','订单id'),
('tmerclub-order-314','1','1000','订单id'),
('tmerclub-order-315','1','1000','订单id'),
('tmerclub-order-316','1','1000','订单id'),
('tmerclub-order-317','1','1000','订单id'),
('tmerclub-order-318','1','1000','订单id'),
('tmerclub-order-319','1','1000','订单id'),
('tmerclub-order-320','1','1000','订单id'),
('tmerclub-order-321','1','1000','订单id'),
('tmerclub-order-322','1','1000','订单id'),
('tmerclub-order-323','1','1000','订单id'),
('tmerclub-order-324','1','1000','订单id'),
('tmerclub-order-325','1','1000','订单id'),
('tmerclub-order-326','1','1000','订单id'),
('tmerclub-order-327','1','1000','订单id'),
('tmerclub-order-328','1','1000','订单id'),
('tmerclub-order-329','1','1000','订单id'),
('tmerclub-order-330','1','1000','订单id'),
('tmerclub-order-331','1','1000','订单id'),
('tmerclub-order-332','1','1000','订单id'),
('tmerclub-order-333','1','1000','订单id'),
('tmerclub-order-334','1','1000','订单id'),
('tmerclub-order-335','1','1000','订单id'),
('tmerclub-order-336','1','1000','订单id'),
('tmerclub-order-337','1','1000','订单id'),
('tmerclub-order-338','1','1000','订单id'),
('tmerclub-order-339','1','1000','订单id'),
('tmerclub-order-340','1','1000','订单id'),
('tmerclub-order-341','1','1000','订单id'),
('tmerclub-order-342','1','1000','订单id'),
('tmerclub-order-343','1','1000','订单id'),
('tmerclub-order-344','1','1000','订单id'),
('tmerclub-order-345','1','1000','订单id'),
('tmerclub-order-346','1','1000','订单id'),
('tmerclub-order-347','1','1000','订单id'),
('tmerclub-order-348','1','1000','订单id'),
('tmerclub-order-349','1','1000','订单id'),
('tmerclub-order-350','1','1000','订单id'),
('tmerclub-order-351','1','1000','订单id'),
('tmerclub-order-352','1','1000','订单id'),
('tmerclub-order-353','1','1000','订单id'),
('tmerclub-order-354','1','1000','订单id'),
('tmerclub-order-355','1','1000','订单id'),
('tmerclub-order-356','1','1000','订单id'),
('tmerclub-order-357','1','1000','订单id'),
('tmerclub-order-358','1','1000','订单id'),
('tmerclub-order-359','1','1000','订单id'),
('tmerclub-order-360','1','1000','订单id'),
('tmerclub-order-361','1','1000','订单id'),
('tmerclub-order-362','1','1000','订单id'),
('tmerclub-order-363','1','1000','订单id'),
('tmerclub-order-364','1','1000','订单id'),
('tmerclub-order-365','1','1000','订单id'),
('tmerclub-order-366','1','1000','订单id'),
('tmerclub-order-367','1','1000','订单id'),
('tmerclub-order-368','1','1000','订单id'),
('tmerclub-order-369','1','1000','订单id'),
('tmerclub-order-370','1','1000','订单id'),
('tmerclub-order-371','1','1000','订单id'),
('tmerclub-order-372','1','1000','订单id'),
('tmerclub-order-373','1','1000','订单id'),
('tmerclub-order-374','1','1000','订单id'),
('tmerclub-order-375','1','1000','订单id'),
('tmerclub-order-376','1','1000','订单id'),
('tmerclub-order-377','1','1000','订单id'),
('tmerclub-order-378','1','1000','订单id'),
('tmerclub-order-379','1','1000','订单id'),
('tmerclub-order-380','1','1000','订单id'),
('tmerclub-order-381','1','1000','订单id'),
('tmerclub-order-382','1','1000','订单id'),
('tmerclub-order-383','1','1000','订单id'),
('tmerclub-order-384','1','1000','订单id'),
('tmerclub-order-385','1','1000','订单id'),
('tmerclub-order-386','1','1000','订单id'),
('tmerclub-order-387','1','1000','订单id'),
('tmerclub-order-388','1','1000','订单id'),
('tmerclub-order-389','1','1000','订单id'),
('tmerclub-order-390','1','1000','订单id'),
('tmerclub-order-391','1','1000','订单id'),
('tmerclub-order-392','1','1000','订单id'),
('tmerclub-order-393','1','1000','订单id'),
('tmerclub-order-394','1','1000','订单id'),
('tmerclub-order-395','1','1000','订单id'),
('tmerclub-order-396','1','1000','订单id'),
('tmerclub-order-397','1','1000','订单id'),
('tmerclub-order-398','1','1000','订单id'),
('tmerclub-order-399','1','1000','订单id'),
('tmerclub-order-400','1','1000','订单id'),
('tmerclub-order-401','1','1000','订单id'),
('tmerclub-order-402','1','1000','订单id'),
('tmerclub-order-403','1','1000','订单id'),
('tmerclub-order-404','1','1000','订单id'),
('tmerclub-order-405','1','1000','订单id'),
('tmerclub-order-406','1','1000','订单id'),
('tmerclub-order-407','1','1000','订单id'),
('tmerclub-order-408','1','1000','订单id'),
('tmerclub-order-409','1','1000','订单id'),
('tmerclub-order-410','1','1000','订单id'),
('tmerclub-order-411','1','1000','订单id'),
('tmerclub-order-412','1','1000','订单id'),
('tmerclub-order-413','1','1000','订单id'),
('tmerclub-order-414','1','1000','订单id'),
('tmerclub-order-415','1','1000','订单id'),
('tmerclub-order-416','1','1000','订单id'),
('tmerclub-order-417','1','1000','订单id'),
('tmerclub-order-418','1','1000','订单id'),
('tmerclub-order-419','1','1000','订单id'),
('tmerclub-order-420','1','1000','订单id'),
('tmerclub-order-421','1','1000','订单id'),
('tmerclub-order-422','1','1000','订单id'),
('tmerclub-order-423','1','1000','订单id'),
('tmerclub-order-424','1','1000','订单id'),
('tmerclub-order-425','1','1000','订单id'),
('tmerclub-order-426','1','1000','订单id'),
('tmerclub-order-427','1','1000','订单id'),
('tmerclub-order-428','1','1000','订单id'),
('tmerclub-order-429','1','1000','订单id'),
('tmerclub-order-430','1','1000','订单id'),
('tmerclub-order-431','1','1000','订单id'),
('tmerclub-order-432','1','1000','订单id'),
('tmerclub-order-433','1','1000','订单id'),
('tmerclub-order-434','1','1000','订单id'),
('tmerclub-order-435','1','1000','订单id'),
('tmerclub-order-436','1','1000','订单id'),
('tmerclub-order-437','1','1000','订单id'),
('tmerclub-order-438','1','1000','订单id'),
('tmerclub-order-439','1','1000','订单id'),
('tmerclub-order-440','1','1000','订单id'),
('tmerclub-order-441','1','1000','订单id'),
('tmerclub-order-442','1','1000','订单id'),
('tmerclub-order-443','1','1000','订单id'),
('tmerclub-order-444','1','1000','订单id'),
('tmerclub-order-445','1','1000','订单id'),
('tmerclub-order-446','1','1000','订单id'),
('tmerclub-order-447','1','1000','订单id'),
('tmerclub-order-448','1','1000','订单id'),
('tmerclub-order-449','1','1000','订单id'),
('tmerclub-order-450','1','1000','订单id'),
('tmerclub-order-451','1','1000','订单id'),
('tmerclub-order-452','1','1000','订单id'),
('tmerclub-order-453','1','1000','订单id'),
('tmerclub-order-454','1','1000','订单id'),
('tmerclub-order-455','1','1000','订单id'),
('tmerclub-order-456','1','1000','订单id'),
('tmerclub-order-457','1','1000','订单id'),
('tmerclub-order-458','1','1000','订单id'),
('tmerclub-order-459','1','1000','订单id'),
('tmerclub-order-460','1','1000','订单id'),
('tmerclub-order-461','1','1000','订单id'),
('tmerclub-order-462','1','1000','订单id'),
('tmerclub-order-463','1','1000','订单id'),
('tmerclub-order-464','1','1000','订单id'),
('tmerclub-order-465','1','1000','订单id'),
('tmerclub-order-466','1','1000','订单id'),
('tmerclub-order-467','1','1000','订单id'),
('tmerclub-order-468','1','1000','订单id'),
('tmerclub-order-469','1','1000','订单id'),
('tmerclub-order-470','1','1000','订单id'),
('tmerclub-order-471','1','1000','订单id'),
('tmerclub-order-472','1','1000','订单id'),
('tmerclub-order-473','1','1000','订单id'),
('tmerclub-order-474','1','1000','订单id'),
('tmerclub-order-475','1','1000','订单id'),
('tmerclub-order-476','1','1000','订单id'),
('tmerclub-order-477','1','1000','订单id'),
('tmerclub-order-478','1','1000','订单id'),
('tmerclub-order-479','1','1000','订单id'),
('tmerclub-order-480','1','1000','订单id'),
('tmerclub-order-481','1','1000','订单id'),
('tmerclub-order-482','1','1000','订单id'),
('tmerclub-order-483','1','1000','订单id'),
('tmerclub-order-484','1','1000','订单id'),
('tmerclub-order-485','1','1000','订单id'),
('tmerclub-order-486','1','1000','订单id'),
('tmerclub-order-487','1','1000','订单id'),
('tmerclub-order-488','1','1000','订单id'),
('tmerclub-order-489','1','1000','订单id'),
('tmerclub-order-490','1','1000','订单id'),
('tmerclub-order-491','1','1000','订单id'),
('tmerclub-order-492','1','1000','订单id'),
('tmerclub-order-493','1','1000','订单id'),
('tmerclub-order-494','1','1000','订单id'),
('tmerclub-order-495','1','1000','订单id'),
('tmerclub-order-496','1','1000','订单id'),
('tmerclub-order-497','1','1000','订单id'),
('tmerclub-order-498','1','1000','订单id'),
('tmerclub-order-499','1','1000','订单id'),
('tmerclub-order-500','1','1000','订单id'),
('tmerclub-order-501','1','1000','订单id'),
('tmerclub-order-502','1','1000','订单id'),
('tmerclub-order-503','1','1000','订单id'),
('tmerclub-order-504','1','1000','订单id'),
('tmerclub-order-505','1','1000','订单id'),
('tmerclub-order-506','1','1000','订单id'),
('tmerclub-order-507','1','1000','订单id'),
('tmerclub-order-508','1','1000','订单id'),
('tmerclub-order-509','1','1000','订单id'),
('tmerclub-order-510','1','1000','订单id'),
('tmerclub-order-511','1','1000','订单id'),
('tmerclub-order-512','1','1000','订单id'),
('tmerclub-order-513','1','1000','订单id'),
('tmerclub-order-514','1','1000','订单id'),
('tmerclub-order-515','1','1000','订单id'),
('tmerclub-order-516','1','1000','订单id'),
('tmerclub-order-517','1','1000','订单id'),
('tmerclub-order-518','1','1000','订单id'),
('tmerclub-order-519','1','1000','订单id'),
('tmerclub-order-520','1','1000','订单id'),
('tmerclub-order-521','1','1000','订单id'),
('tmerclub-order-522','1','1000','订单id'),
('tmerclub-order-523','1','1000','订单id'),
('tmerclub-order-524','1','1000','订单id'),
('tmerclub-order-525','1','1000','订单id'),
('tmerclub-order-526','1','1000','订单id'),
('tmerclub-order-527','1','1000','订单id'),
('tmerclub-order-528','1','1000','订单id'),
('tmerclub-order-529','1','1000','订单id'),
('tmerclub-order-530','1','1000','订单id'),
('tmerclub-order-531','1','1000','订单id'),
('tmerclub-order-532','1','1000','订单id'),
('tmerclub-order-533','1','1000','订单id'),
('tmerclub-order-534','1','1000','订单id'),
('tmerclub-order-535','1','1000','订单id'),
('tmerclub-order-536','1','1000','订单id'),
('tmerclub-order-537','1','1000','订单id'),
('tmerclub-order-538','1','1000','订单id'),
('tmerclub-order-539','1','1000','订单id'),
('tmerclub-order-540','1','1000','订单id'),
('tmerclub-order-541','1','1000','订单id'),
('tmerclub-order-542','1','1000','订单id'),
('tmerclub-order-543','1','1000','订单id'),
('tmerclub-order-544','1','1000','订单id'),
('tmerclub-order-545','1','1000','订单id'),
('tmerclub-order-546','1','1000','订单id'),
('tmerclub-order-547','1','1000','订单id'),
('tmerclub-order-548','1','1000','订单id'),
('tmerclub-order-549','1','1000','订单id'),
('tmerclub-order-550','1','1000','订单id'),
('tmerclub-order-551','1','1000','订单id'),
('tmerclub-order-552','1','1000','订单id'),
('tmerclub-order-553','1','1000','订单id'),
('tmerclub-order-554','1','1000','订单id'),
('tmerclub-order-555','1','1000','订单id'),
('tmerclub-order-556','1','1000','订单id'),
('tmerclub-order-557','1','1000','订单id'),
('tmerclub-order-558','1','1000','订单id'),
('tmerclub-order-559','1','1000','订单id'),
('tmerclub-order-560','1','1000','订单id'),
('tmerclub-order-561','1','1000','订单id'),
('tmerclub-order-562','1','1000','订单id'),
('tmerclub-order-563','1','1000','订单id'),
('tmerclub-order-564','1','1000','订单id'),
('tmerclub-order-565','1','1000','订单id'),
('tmerclub-order-566','1','1000','订单id'),
('tmerclub-order-567','1','1000','订单id'),
('tmerclub-order-568','1','1000','订单id'),
('tmerclub-order-569','1','1000','订单id'),
('tmerclub-order-570','1','1000','订单id'),
('tmerclub-order-571','1','1000','订单id'),
('tmerclub-order-572','1','1000','订单id'),
('tmerclub-order-573','1','1000','订单id'),
('tmerclub-order-574','1','1000','订单id'),
('tmerclub-order-575','1','1000','订单id'),
('tmerclub-order-576','1','1000','订单id'),
('tmerclub-order-577','1','1000','订单id'),
('tmerclub-order-578','1','1000','订单id'),
('tmerclub-order-579','1','1000','订单id'),
('tmerclub-order-580','1','1000','订单id'),
('tmerclub-order-581','1','1000','订单id'),
('tmerclub-order-582','1','1000','订单id'),
('tmerclub-order-583','1','1000','订单id'),
('tmerclub-order-584','1','1000','订单id'),
('tmerclub-order-585','1','1000','订单id'),
('tmerclub-order-586','1','1000','订单id'),
('tmerclub-order-587','1','1000','订单id'),
('tmerclub-order-588','1','1000','订单id'),
('tmerclub-order-589','1','1000','订单id'),
('tmerclub-order-590','1','1000','订单id'),
('tmerclub-order-591','1','1000','订单id'),
('tmerclub-order-592','1','1000','订单id'),
('tmerclub-order-593','1','1000','订单id'),
('tmerclub-order-594','1','1000','订单id'),
('tmerclub-order-595','1','1000','订单id'),
('tmerclub-order-596','1','1000','订单id'),
('tmerclub-order-597','1','1000','订单id'),
('tmerclub-order-598','1','1000','订单id'),
('tmerclub-order-599','1','1000','订单id'),
('tmerclub-order-600','1','1000','订单id'),
('tmerclub-order-601','1','1000','订单id'),
('tmerclub-order-602','1','1000','订单id'),
('tmerclub-order-603','1','1000','订单id'),
('tmerclub-order-604','1','1000','订单id'),
('tmerclub-order-605','1','1000','订单id'),
('tmerclub-order-606','1','1000','订单id'),
('tmerclub-order-607','1','1000','订单id'),
('tmerclub-order-608','1','1000','订单id'),
('tmerclub-order-609','1','1000','订单id'),
('tmerclub-order-610','1','1000','订单id'),
('tmerclub-order-611','1','1000','订单id'),
('tmerclub-order-612','1','1000','订单id'),
('tmerclub-order-613','1','1000','订单id'),
('tmerclub-order-614','1','1000','订单id'),
('tmerclub-order-615','1','1000','订单id'),
('tmerclub-order-616','1','1000','订单id'),
('tmerclub-order-617','1','1000','订单id'),
('tmerclub-order-618','1','1000','订单id'),
('tmerclub-order-619','1','1000','订单id'),
('tmerclub-order-620','1','1000','订单id'),
('tmerclub-order-621','1','1000','订单id'),
('tmerclub-order-622','1','1000','订单id'),
('tmerclub-order-623','1','1000','订单id'),
('tmerclub-order-624','1','1000','订单id'),
('tmerclub-order-625','1','1000','订单id'),
('tmerclub-order-626','1','1000','订单id'),
('tmerclub-order-627','1','1000','订单id'),
('tmerclub-order-628','1','1000','订单id'),
('tmerclub-order-629','1','1000','订单id'),
('tmerclub-order-630','1','1000','订单id'),
('tmerclub-order-631','1','1000','订单id'),
('tmerclub-order-632','1','1000','订单id'),
('tmerclub-order-633','1','1000','订单id'),
('tmerclub-order-634','1','1000','订单id'),
('tmerclub-order-635','1','1000','订单id'),
('tmerclub-order-636','1','1000','订单id'),
('tmerclub-order-637','1','1000','订单id'),
('tmerclub-order-638','1','1000','订单id'),
('tmerclub-order-639','1','1000','订单id'),
('tmerclub-order-640','1','1000','订单id'),
('tmerclub-order-641','1','1000','订单id'),
('tmerclub-order-642','1','1000','订单id'),
('tmerclub-order-643','1','1000','订单id'),
('tmerclub-order-644','1','1000','订单id'),
('tmerclub-order-645','1','1000','订单id'),
('tmerclub-order-646','1','1000','订单id'),
('tmerclub-order-647','1','1000','订单id'),
('tmerclub-order-648','1','1000','订单id'),
('tmerclub-order-649','1','1000','订单id'),
('tmerclub-order-650','1','1000','订单id'),
('tmerclub-order-651','1','1000','订单id'),
('tmerclub-order-652','1','1000','订单id'),
('tmerclub-order-653','1','1000','订单id'),
('tmerclub-order-654','1','1000','订单id'),
('tmerclub-order-655','1','1000','订单id'),
('tmerclub-order-656','1','1000','订单id'),
('tmerclub-order-657','1','1000','订单id'),
('tmerclub-order-658','1','1000','订单id'),
('tmerclub-order-659','1','1000','订单id'),
('tmerclub-order-660','1','1000','订单id'),
('tmerclub-order-661','1','1000','订单id'),
('tmerclub-order-662','1','1000','订单id'),
('tmerclub-order-663','1','1000','订单id'),
('tmerclub-order-664','1','1000','订单id'),
('tmerclub-order-665','1','1000','订单id'),
('tmerclub-order-666','1','1000','订单id'),
('tmerclub-order-667','1','1000','订单id'),
('tmerclub-order-668','1','1000','订单id'),
('tmerclub-order-669','1','1000','订单id'),
('tmerclub-order-670','1','1000','订单id'),
('tmerclub-order-671','1','1000','订单id'),
('tmerclub-order-672','1','1000','订单id'),
('tmerclub-order-673','1','1000','订单id'),
('tmerclub-order-674','1','1000','订单id'),
('tmerclub-order-675','1','1000','订单id'),
('tmerclub-order-676','1','1000','订单id'),
('tmerclub-order-677','1','1000','订单id'),
('tmerclub-order-678','1','1000','订单id'),
('tmerclub-order-679','1','1000','订单id'),
('tmerclub-order-680','1','1000','订单id'),
('tmerclub-order-681','1','1000','订单id'),
('tmerclub-order-682','1','1000','订单id'),
('tmerclub-order-683','1','1000','订单id'),
('tmerclub-order-684','1','1000','订单id'),
('tmerclub-order-685','1','1000','订单id'),
('tmerclub-order-686','1','1000','订单id'),
('tmerclub-order-687','1','1000','订单id'),
('tmerclub-order-688','1','1000','订单id'),
('tmerclub-order-689','1','1000','订单id'),
('tmerclub-order-690','1','1000','订单id'),
('tmerclub-order-691','1','1000','订单id'),
('tmerclub-order-692','1','1000','订单id'),
('tmerclub-order-693','1','1000','订单id'),
('tmerclub-order-694','1','1000','订单id'),
('tmerclub-order-695','1','1000','订单id'),
('tmerclub-order-696','1','1000','订单id'),
('tmerclub-order-697','1','1000','订单id'),
('tmerclub-order-698','1','1000','订单id'),
('tmerclub-order-699','1','1000','订单id'),
('tmerclub-order-700','1','1000','订单id'),
('tmerclub-order-701','1','1000','订单id'),
('tmerclub-order-702','1','1000','订单id'),
('tmerclub-order-703','1','1000','订单id'),
('tmerclub-order-704','1','1000','订单id'),
('tmerclub-order-705','1','1000','订单id'),
('tmerclub-order-706','1','1000','订单id'),
('tmerclub-order-707','1','1000','订单id'),
('tmerclub-order-708','1','1000','订单id'),
('tmerclub-order-709','1','1000','订单id'),
('tmerclub-order-710','1','1000','订单id'),
('tmerclub-order-711','1','1000','订单id'),
('tmerclub-order-712','1','1000','订单id'),
('tmerclub-order-713','1','1000','订单id'),
('tmerclub-order-714','1','1000','订单id'),
('tmerclub-order-715','1','1000','订单id'),
('tmerclub-order-716','1','1000','订单id'),
('tmerclub-order-717','1','1000','订单id'),
('tmerclub-order-718','1','1000','订单id'),
('tmerclub-order-719','1','1000','订单id'),
('tmerclub-order-720','1','1000','订单id'),
('tmerclub-order-721','1','1000','订单id'),
('tmerclub-order-722','1','1000','订单id'),
('tmerclub-order-723','1','1000','订单id'),
('tmerclub-order-724','1','1000','订单id'),
('tmerclub-order-725','1','1000','订单id'),
('tmerclub-order-726','1','1000','订单id'),
('tmerclub-order-727','1','1000','订单id'),
('tmerclub-order-728','1','1000','订单id'),
('tmerclub-order-729','1','1000','订单id'),
('tmerclub-order-730','1','1000','订单id'),
('tmerclub-order-731','1','1000','订单id'),
('tmerclub-order-732','1','1000','订单id'),
('tmerclub-order-733','1','1000','订单id'),
('tmerclub-order-734','1','1000','订单id'),
('tmerclub-order-735','1','1000','订单id'),
('tmerclub-order-736','1','1000','订单id'),
('tmerclub-order-737','1','1000','订单id'),
('tmerclub-order-738','1','1000','订单id'),
('tmerclub-order-739','1','1000','订单id'),
('tmerclub-order-740','1','1000','订单id'),
('tmerclub-order-741','1','1000','订单id'),
('tmerclub-order-742','1','1000','订单id'),
('tmerclub-order-743','1','1000','订单id'),
('tmerclub-order-744','1','1000','订单id'),
('tmerclub-order-745','1','1000','订单id'),
('tmerclub-order-746','1','1000','订单id'),
('tmerclub-order-747','1','1000','订单id'),
('tmerclub-order-748','1','1000','订单id'),
('tmerclub-order-749','1','1000','订单id'),
('tmerclub-order-750','1','1000','订单id'),
('tmerclub-order-751','1','1000','订单id'),
('tmerclub-order-752','1','1000','订单id'),
('tmerclub-order-753','1','1000','订单id'),
('tmerclub-order-754','1','1000','订单id'),
('tmerclub-order-755','1','1000','订单id'),
('tmerclub-order-756','1','1000','订单id'),
('tmerclub-order-757','1','1000','订单id'),
('tmerclub-order-758','1','1000','订单id'),
('tmerclub-order-759','1','1000','订单id'),
('tmerclub-order-760','1','1000','订单id'),
('tmerclub-order-761','1','1000','订单id'),
('tmerclub-order-762','1','1000','订单id'),
('tmerclub-order-763','1','1000','订单id'),
('tmerclub-order-764','1','1000','订单id'),
('tmerclub-order-765','1','1000','订单id'),
('tmerclub-order-766','1','1000','订单id'),
('tmerclub-order-767','1','1000','订单id'),
('tmerclub-order-768','1','1000','订单id'),
('tmerclub-order-769','1','1000','订单id'),
('tmerclub-order-770','1','1000','订单id'),
('tmerclub-order-771','1','1000','订单id'),
('tmerclub-order-772','1','1000','订单id'),
('tmerclub-order-773','1','1000','订单id'),
('tmerclub-order-774','1','1000','订单id'),
('tmerclub-order-775','1','1000','订单id'),
('tmerclub-order-776','1','1000','订单id'),
('tmerclub-order-777','1','1000','订单id'),
('tmerclub-order-778','1','1000','订单id'),
('tmerclub-order-779','1','1000','订单id'),
('tmerclub-order-780','1','1000','订单id'),
('tmerclub-order-781','1','1000','订单id'),
('tmerclub-order-782','1','1000','订单id'),
('tmerclub-order-783','1','1000','订单id'),
('tmerclub-order-784','1','1000','订单id'),
('tmerclub-order-785','1','1000','订单id'),
('tmerclub-order-786','1','1000','订单id'),
('tmerclub-order-787','1','1000','订单id'),
('tmerclub-order-788','1','1000','订单id'),
('tmerclub-order-789','1','1000','订单id'),
('tmerclub-order-790','1','1000','订单id'),
('tmerclub-order-791','1','1000','订单id'),
('tmerclub-order-792','1','1000','订单id'),
('tmerclub-order-793','1','1000','订单id'),
('tmerclub-order-794','1','1000','订单id'),
('tmerclub-order-795','1','1000','订单id'),
('tmerclub-order-796','1','1000','订单id'),
('tmerclub-order-797','1','1000','订单id'),
('tmerclub-order-798','1','1000','订单id'),
('tmerclub-order-799','1','1000','订单id'),
('tmerclub-order-800','1','1000','订单id'),
('tmerclub-order-801','1','1000','订单id'),
('tmerclub-order-802','1','1000','订单id'),
('tmerclub-order-803','1','1000','订单id'),
('tmerclub-order-804','1','1000','订单id'),
('tmerclub-order-805','1','1000','订单id'),
('tmerclub-order-806','1','1000','订单id'),
('tmerclub-order-807','1','1000','订单id'),
('tmerclub-order-808','1','1000','订单id'),
('tmerclub-order-809','1','1000','订单id'),
('tmerclub-order-810','1','1000','订单id'),
('tmerclub-order-811','1','1000','订单id'),
('tmerclub-order-812','1','1000','订单id'),
('tmerclub-order-813','1','1000','订单id'),
('tmerclub-order-814','1','1000','订单id'),
('tmerclub-order-815','1','1000','订单id'),
('tmerclub-order-816','1','1000','订单id'),
('tmerclub-order-817','1','1000','订单id'),
('tmerclub-order-818','1','1000','订单id'),
('tmerclub-order-819','1','1000','订单id'),
('tmerclub-order-820','1','1000','订单id'),
('tmerclub-order-821','1','1000','订单id'),
('tmerclub-order-822','1','1000','订单id'),
('tmerclub-order-823','1','1000','订单id'),
('tmerclub-order-824','1','1000','订单id'),
('tmerclub-order-825','1','1000','订单id'),
('tmerclub-order-826','1','1000','订单id'),
('tmerclub-order-827','1','1000','订单id'),
('tmerclub-order-828','1','1000','订单id'),
('tmerclub-order-829','1','1000','订单id'),
('tmerclub-order-830','1','1000','订单id'),
('tmerclub-order-831','1','1000','订单id'),
('tmerclub-order-832','1','1000','订单id'),
('tmerclub-order-833','1','1000','订单id'),
('tmerclub-order-834','1','1000','订单id'),
('tmerclub-order-835','1','1000','订单id'),
('tmerclub-order-836','1','1000','订单id'),
('tmerclub-order-837','1','1000','订单id'),
('tmerclub-order-838','1','1000','订单id'),
('tmerclub-order-839','1','1000','订单id'),
('tmerclub-order-840','1','1000','订单id'),
('tmerclub-order-841','1','1000','订单id'),
('tmerclub-order-842','1','1000','订单id'),
('tmerclub-order-843','1','1000','订单id'),
('tmerclub-order-844','1','1000','订单id'),
('tmerclub-order-845','1','1000','订单id'),
('tmerclub-order-846','1','1000','订单id'),
('tmerclub-order-847','1','1000','订单id'),
('tmerclub-order-848','1','1000','订单id'),
('tmerclub-order-849','1','1000','订单id'),
('tmerclub-order-850','1','1000','订单id'),
('tmerclub-order-851','1','1000','订单id'),
('tmerclub-order-852','1','1000','订单id'),
('tmerclub-order-853','1','1000','订单id'),
('tmerclub-order-854','1','1000','订单id'),
('tmerclub-order-855','1','1000','订单id'),
('tmerclub-order-856','1','1000','订单id'),
('tmerclub-order-857','1','1000','订单id'),
('tmerclub-order-858','1','1000','订单id'),
('tmerclub-order-859','1','1000','订单id'),
('tmerclub-order-860','1','1000','订单id'),
('tmerclub-order-861','1','1000','订单id'),
('tmerclub-order-862','1','1000','订单id'),
('tmerclub-order-863','1','1000','订单id'),
('tmerclub-order-864','1','1000','订单id'),
('tmerclub-order-865','1','1000','订单id'),
('tmerclub-order-866','1','1000','订单id'),
('tmerclub-order-867','1','1000','订单id'),
('tmerclub-order-868','1','1000','订单id'),
('tmerclub-order-869','1','1000','订单id'),
('tmerclub-order-870','1','1000','订单id'),
('tmerclub-order-871','1','1000','订单id'),
('tmerclub-order-872','1','1000','订单id'),
('tmerclub-order-873','1','1000','订单id'),
('tmerclub-order-874','1','1000','订单id'),
('tmerclub-order-875','1','1000','订单id'),
('tmerclub-order-876','1','1000','订单id'),
('tmerclub-order-877','1','1000','订单id'),
('tmerclub-order-878','1','1000','订单id'),
('tmerclub-order-879','1','1000','订单id'),
('tmerclub-order-880','1','1000','订单id'),
('tmerclub-order-881','1','1000','订单id'),
('tmerclub-order-882','1','1000','订单id'),
('tmerclub-order-883','1','1000','订单id'),
('tmerclub-order-884','1','1000','订单id'),
('tmerclub-order-885','1','1000','订单id'),
('tmerclub-order-886','1','1000','订单id'),
('tmerclub-order-887','1','1000','订单id'),
('tmerclub-order-888','1','1000','订单id'),
('tmerclub-order-889','1','1000','订单id'),
('tmerclub-order-890','1','1000','订单id'),
('tmerclub-order-891','1','1000','订单id'),
('tmerclub-order-892','1','1000','订单id'),
('tmerclub-order-893','1','1000','订单id'),
('tmerclub-order-894','1','1000','订单id'),
('tmerclub-order-895','1','1000','订单id'),
('tmerclub-order-896','1','1000','订单id'),
('tmerclub-order-897','1','1000','订单id'),
('tmerclub-order-898','1','1000','订单id'),
('tmerclub-order-899','1','1000','订单id'),
('tmerclub-order-900','1','1000','订单id'),
('tmerclub-order-901','1','1000','订单id'),
('tmerclub-order-902','1','1000','订单id'),
('tmerclub-order-903','1','1000','订单id'),
('tmerclub-order-904','1','1000','订单id'),
('tmerclub-order-905','1','1000','订单id'),
('tmerclub-order-906','1','1000','订单id'),
('tmerclub-order-907','1','1000','订单id'),
('tmerclub-order-908','1','1000','订单id'),
('tmerclub-order-909','1','1000','订单id'),
('tmerclub-order-910','1','1000','订单id'),
('tmerclub-order-911','1','1000','订单id'),
('tmerclub-order-912','1','1000','订单id'),
('tmerclub-order-913','1','1000','订单id'),
('tmerclub-order-914','1','1000','订单id'),
('tmerclub-order-915','1','1000','订单id'),
('tmerclub-order-916','1','1000','订单id'),
('tmerclub-order-917','1','1000','订单id'),
('tmerclub-order-918','1','1000','订单id'),
('tmerclub-order-919','1','1000','订单id'),
('tmerclub-order-920','1','1000','订单id'),
('tmerclub-order-921','1','1000','订单id'),
('tmerclub-order-922','1','1000','订单id'),
('tmerclub-order-923','1','1000','订单id'),
('tmerclub-order-924','1','1000','订单id'),
('tmerclub-order-925','1','1000','订单id'),
('tmerclub-order-926','1','1000','订单id'),
('tmerclub-order-927','1','1000','订单id'),
('tmerclub-order-928','1','1000','订单id'),
('tmerclub-order-929','1','1000','订单id'),
('tmerclub-order-930','1','1000','订单id'),
('tmerclub-order-931','1','1000','订单id'),
('tmerclub-order-932','1','1000','订单id'),
('tmerclub-order-933','1','1000','订单id'),
('tmerclub-order-934','1','1000','订单id'),
('tmerclub-order-935','1','1000','订单id'),
('tmerclub-order-936','1','1000','订单id'),
('tmerclub-order-937','1','1000','订单id'),
('tmerclub-order-938','1','1000','订单id'),
('tmerclub-order-939','1','1000','订单id'),
('tmerclub-order-940','1','1000','订单id'),
('tmerclub-order-941','1','1000','订单id'),
('tmerclub-order-942','1','1000','订单id'),
('tmerclub-order-943','1','1000','订单id'),
('tmerclub-order-944','1','1000','订单id'),
('tmerclub-order-945','1','1000','订单id'),
('tmerclub-order-946','1','1000','订单id'),
('tmerclub-order-947','1','1000','订单id'),
('tmerclub-order-948','1','1000','订单id'),
('tmerclub-order-949','1','1000','订单id'),
('tmerclub-order-950','1','1000','订单id'),
('tmerclub-order-951','1','1000','订单id'),
('tmerclub-order-952','1','1000','订单id'),
('tmerclub-order-953','1','1000','订单id'),
('tmerclub-order-954','1','1000','订单id'),
('tmerclub-order-955','1','1000','订单id'),
('tmerclub-order-956','1','1000','订单id'),
('tmerclub-order-957','1','1000','订单id'),
('tmerclub-order-958','1','1000','订单id'),
('tmerclub-order-959','1','1000','订单id'),
('tmerclub-order-960','1','1000','订单id'),
('tmerclub-order-961','1','1000','订单id'),
('tmerclub-order-962','1','1000','订单id'),
('tmerclub-order-963','1','1000','订单id'),
('tmerclub-order-964','1','1000','订单id'),
('tmerclub-order-965','1','1000','订单id'),
('tmerclub-order-966','1','1000','订单id'),
('tmerclub-order-967','1','1000','订单id'),
('tmerclub-order-968','1','1000','订单id'),
('tmerclub-order-969','1','1000','订单id'),
('tmerclub-order-970','1','1000','订单id'),
('tmerclub-order-971','1','1000','订单id'),
('tmerclub-order-972','1','1000','订单id'),
('tmerclub-order-973','1','1000','订单id'),
('tmerclub-order-974','1','1000','订单id'),
('tmerclub-order-975','1','1000','订单id'),
('tmerclub-order-976','1','1000','订单id'),
('tmerclub-order-977','1','1000','订单id'),
('tmerclub-order-978','1','1000','订单id'),
('tmerclub-order-979','1','1000','订单id'),
('tmerclub-order-980','1','1000','订单id'),
('tmerclub-order-981','1','1000','订单id'),
('tmerclub-order-982','1','1000','订单id'),
('tmerclub-order-983','1','1000','订单id'),
('tmerclub-order-984','1','1000','订单id'),
('tmerclub-order-985','1','1000','订单id'),
('tmerclub-order-986','1','1000','订单id'),
('tmerclub-order-987','1','1000','订单id'),
('tmerclub-order-988','1','1000','订单id'),
('tmerclub-order-989','1','1000','订单id'),
('tmerclub-order-990','1','1000','订单id'),
('tmerclub-order-991','1','1000','订单id'),
('tmerclub-order-992','1','1000','订单id'),
('tmerclub-order-993','1','1000','订单id'),
('tmerclub-order-994','1','1000','订单id'),
('tmerclub-order-995','1','1000','订单id'),
('tmerclub-order-996','1','1000','订单id'),
('tmerclub-order-997','1','1000','订单id'),
('tmerclub-order-998','1','1000','订单id'),
('tmerclub-order-999','1','1000','订单id');



/*Table structure for table `undo_log` */

DROP TABLE IF EXISTS `undo_log`;

CREATE TABLE `undo_log` (
  `id` bigint NOT NULL AUTO_INCREMENT,
  `branch_id` bigint NOT NULL,
  `xid` varchar(100)  NOT NULL,
  `context` varchar(128)  NOT NULL,
  `rollback_info` longblob NOT NULL,
  `log_status` int NOT NULL,
  `log_created` datetime NOT NULL,
  `log_modified` datetime NOT NULL,
  PRIMARY KEY (`id`),
  UNIQUE KEY `ux_undo_log` (`xid`,`branch_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci;

/*Data for the table `undo_log` */

/*!40101 SET SQL_MODE=@OLD_SQL_MODE */;
/*!40014 SET UNIQUE_CHECKS=@OLD_UNIQUE_CHECKS */;
/*!40111 SET SQL_NOTES=@OLD_SQL_NOTES */;
